# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Query Optimizer
---------------

This is a heuristic-based query optimizer:
    → Perform most restrictive selection early
    → Perform all selections before joins
    → Predicate/Limit/Projection pushdowns
    → Join ordering based on cardinality

    -> Can we make a set of OR statement an IN statement
"""

# distinct and group by is illogical
#



from fastapi import FastAPI, Request
from fastapi.responses import ORJSONResponse
import os
import uvicorn

trino = FastAPI()

@trino.post("/v1/statement", response_class=ORJSONResponse)
async def read_main(request: Request):
    print(request)
    return {
        "id": 1,
        "stats": {"byes_read":2000},
        "infoUri": "",
        "columns": [{"name":"fruit","type":"varchar"}, {"name":"color","type":"varchar"}],
        "data": [
            ['Apple', 'green'],
            ['Banana', 'yellow'],
            ['Orange', 'orange'],
            ['Strawberry', 'red']
        ]
    }

# tell the server to start
if __name__ == "__main__":
    uvicorn.run(
        "trino_api:trino",
        host="0.0.0.0",
        port=int(os.environ.get("PORT", 8080)),
        lifespan="on",
    )